<?xml version="1.0" encoding="ISO-8859-1"?>
<!-- $Id: docbook.xsl,v 1.7 2005/08/02 06:23:36 toms Exp $ -->
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:exsl="http://exslt.org/common"
    xmlns:suse="urn:x-suse:namespace:1.0"
    extension-element-prefixes="exsl suse">

<!-- ***** Example of a *.desktop entry *****

[Desktop Entry]
Name=SUSE LINUX Userguide (English)
Name[de]=SUSE LINUX Benutzerhandbuch (Englisch)
Name[en]=SUSE LINUX Userguide (English)
Comment=SUSE LINUX Userguide (English).
Comment[de]=Das »SUSE LINUX Benutzerhandbuch« in englischer Sprache.
Comment[en]=SUSE LINUX Userguide (English).
DocPath=@defaultdocdir@/@name@/html/index.html
Icon=document2
X-DOC-Identifier=@id@
X-DOC-SearchMethod=Htdig
X-DOC-Weight=-1000
X-DOC-SearchEnabledDefault=true

-->

<xsl:include href="http://docbook.sourceforge.net/release/xsl/current/html/pi.xsl"/>
<xsl:include href="http://docbook.sourceforge.net/release/xsl/current/html/chunker.xsl"/>
<xsl:include href="http://docbook.sourceforge.net/release/xsl/current/html/chunk-common.xsl"/>
<xsl:include href="http://docbook.sourceforge.net/release/xsl/current/lib/lib.xsl"/>
<xsl:include href="http://docbook.sourceforge.net/release/xsl/current/html/param.xsl"/>
<xsl:include href="http://docbook.sourceforge.net/release/xsl/current/common/l10n.xsl"/>

<xsl:output method="text" encoding="UTF-8"/>
<xsl:strip-space elements="*"/>

<!-- ========================================================== -->
<!--                    Parameter                               -->
<!-- use.id.as.filename: Use id attribute as filename instead of
                         "standard" numbering schema            -->
<xsl:param name="use.id.as.filename"
           select="1"/>

<!-- desktop.ext: Each filename contains this suffix            -->
<xsl:param name="desktop.ext"
           select="'.desktop'"/>

<!-- root.filename: The "main" file for all desktop files       -->
<xsl:param name="root.filename"
           select="concat('index',$desktop.ext)"/>

<!-- directory.filename: The filename for desktop files for
                         directories                            -->
<xsl:param name="directory.filename"
           select="'.directory'"/>

<!-- docpath: Inserts string in desktop files DocPath           -->
<xsl:param name="docpath"
           select="'@PATH@/'"/>

<!-- outputdir: Sets the output directory for each desktop file -->
<xsl:param name="outputdir"
           select="'desktop/'"/>

<!-- uselang: If not empty, each desktop entry contains
              "...[lang]"                                       -->
<xsl:param name="uselang"
           select="1"/>

<!-- desktop.encoding: Use selected encoding for each file      -->
<xsl:param name="desktop.encoding"
           select="'UTF-8'"/>

<!-- debug: Prints some debugging messages                      -->
<xsl:param name="debug"
           select="1"/>

<!-- rootid: Process only this element and their childs         -->
<xsl:param name="rootid"/>


<xsl:key name="id" match="*" use="@id|@xml:id"/>


<xsl:param name="suse:lang">
    <xsl:choose>
        <xsl:when test="/book/@lang">
            <xsl:value-of select="/book/@lang"/>
        </xsl:when>
        <xsl:when test="/book/@xml:lang">
            <xsl:value-of select="/book/@xml:lang"/>
        </xsl:when>
        <xsl:when test="/set/@lang">
            <xsl:value-of select="/set/@lang"/>
        </xsl:when>
        <xsl:otherwise><!-- empty --></xsl:otherwise>
    </xsl:choose>
</xsl:param>

<!-- ========================================================== -->

<xsl:template name="suse:keyvalue">
   <xsl:param name="key"/>
   <xsl:param name="value"/>
   <xsl:param name="printlang" select="0"/>

   <xsl:value-of select="$key"/>
   <xsl:if test="$printlang=1 and $suse:lang and $uselang and $suse:lang!='en'">
      <xsl:text>[</xsl:text>
      <xsl:value-of select="$suse:lang"/>
      <xsl:text>]</xsl:text>
   </xsl:if>
   <xsl:text>=</xsl:text>
   <xsl:value-of select="$value"/>
   <xsl:text>&#10;</xsl:text>

</xsl:template>

<!-- ========================================================== -->
<!-- do nothing! -->
<xsl:template match="text()"/>
<xsl:template match="*"/>


<!-- ========================================================== -->
<xsl:template match="/">
   <xsl:if test="$docpath = ''">
      <xsl:message terminate="yes">
         <xsl:text>ERROR: You must specify the path which&#10;</xsl:text>
         <xsl:text>       contains the corresponding HTML files.</xsl:text>
         <xsl:text>SOLUTION: Try it with --stringparam docpath "YOUR_PATH"</xsl:text>
      </xsl:message>
   </xsl:if>
   <xsl:message>Generating .desktop files </xsl:message>
   <xsl:choose>
    <xsl:when test="$rootid != ''">
      <xsl:choose>
        <xsl:when test="count(key('id',$rootid)) = 0">
          <xsl:message terminate="yes">
            <xsl:text>ID '</xsl:text>
            <xsl:value-of select="$rootid"/>
            <xsl:text>' not found in document.</xsl:text>
          </xsl:message>
        </xsl:when>
        <xsl:otherwise>
          <xsl:message> for rootid="<xsl:value-of select="$rootid"/> ...&#10;</xsl:message>
          <xsl:apply-templates select="key('id',$rootid)" />
        </xsl:otherwise>
      </xsl:choose>
    </xsl:when>
    <xsl:otherwise>
      <xsl:message>...&#10;</xsl:message>
      <xsl:apply-templates/>
    </xsl:otherwise>
   </xsl:choose>

</xsl:template>

<xsl:template match="set">
   <xsl:apply-templates/>
</xsl:template>

<xsl:template match="book">
   <xsl:call-template name="suse:printtitle"/>
   <xsl:variable name="title">
      <xsl:choose>
         <xsl:when test="title">
            <xsl:value-of select="normalize-space(title)"/>
         </xsl:when>
         <xsl:when test="bookinfo/title">
            <xsl:value-of select="normalize-space(bookinfo/title)"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="bookinfo/productname"/><!-- Novdoc compatibility -->
         </xsl:otherwise>
      </xsl:choose>
   </xsl:variable>
   <xsl:variable name="subtitle">
      <xsl:choose>
         <xsl:when test="subtitle">
            <xsl:value-of select="normalize-space(subtitle)"/>
         </xsl:when>
         <xsl:when test="bookinfo/subtitle">
            <xsl:value-of select="normalize-space(bookinfo/subtitle)"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:value-of select="bookinfo/titleabbrev"/><!-- Novdoc compatibility -->
         </xsl:otherwise>
      </xsl:choose>
   </xsl:variable>
   <!--<xsl:text>&#10;</xsl:text>-->

   <xsl:call-template name="suse:writechunk">
        <xsl:with-param name="filename" select="$directory.filename" />
        <xsl:with-param name="filecontent">
            <xsl:text>[Desktop Entry]&#10;</xsl:text>

            <xsl:call-template name="suse:keyvalue">
               <xsl:with-param name="key">Name</xsl:with-param>
               <xsl:with-param name="value" select="normalize-space(concat($title, ' ', $subtitle))"/>
               <xsl:with-param name="printlang" select="1"/>
            </xsl:call-template>

            <xsl:if test="@lang='en'">
               <xsl:call-template name="suse:keyvalue">
                  <xsl:with-param name="key">Name[en]</xsl:with-param>
                  <xsl:with-param name="value" select="normalize-space(concat($title, ' ', $subtitle))"/>
                  <xsl:with-param name="printlang" select="1"/>
               </xsl:call-template>
            </xsl:if>

            <xsl:call-template name="suse:keyvalue">
               <xsl:with-param name="key">Comment</xsl:with-param>
               <xsl:with-param name="value" select="normalize-space(concat($title, ' ', $subtitle))"/>
               <xsl:with-param name="printlang" select="1"/>
            </xsl:call-template>

            <xsl:if test="@lang='en'">
               <xsl:call-template name="suse:keyvalue">
                  <xsl:with-param name="key">Comment[en]</xsl:with-param>
                  <xsl:with-param name="value" select="normalize-space(concat($title, ' ', $subtitle))"/>
                  <xsl:with-param name="printlang" select="1"/>
               </xsl:call-template>
            </xsl:if>

            <xsl:call-template name="suse:keyvalue">
               <xsl:with-param name="key">DocPath</xsl:with-param>
               <xsl:with-param name="value" select="concat($docpath, 'index', $html.ext)"/>
            </xsl:call-template>

            <xsl:text>X-DOC-DocumentType=text/html&#10;</xsl:text>
            <xsl:text>Icon=document2&#10;</xsl:text>
            <xsl:text>X-DOC-Identifier=@id@&#10;</xsl:text>
            <xsl:text>X-DOC-SearchMethod=Htdig&#10;</xsl:text>
            <xsl:text>X-DOC-SearchEnabledDefault=true&#10;</xsl:text>
            <xsl:text>X-DOC-Weight=-1000&#10;</xsl:text>
        </xsl:with-param>
    </xsl:call-template>
    <xsl:apply-templates />

<!--     <xsl:message> html.ext=<xsl:value-of select="$html.ext"/></xsl:message> -->
</xsl:template>


<xsl:template match="part">
   <xsl:variable name="fn">
      <!-- Do number parts only -->
      <xsl:apply-templates select="." mode="recursive-chunk-filename"/>
   </xsl:variable>

   <xsl:call-template name="suse:writechunk">
        <xsl:with-param name="directory" select="substring-before($fn, $html.ext)"/>
        <xsl:with-param name="filename" select="$directory.filename"/>
        <xsl:with-param name="filecontent">
            <xsl:text>[Desktop Entry]&#10;</xsl:text>
            <xsl:call-template name="suse:keyvalue">
               <xsl:with-param name="key">Name</xsl:with-param>
               <xsl:with-param name="value" select="normalize-space(title)"/>
               <xsl:with-param name="printlang" select="1"/>
            </xsl:call-template>

            <xsl:call-template name="suse:keyvalue">
               <xsl:with-param name="key">DocPath</xsl:with-param>
               <xsl:with-param name="value">
                 <xsl:value-of select="$docpath"/>
                 <xsl:call-template name="suse:getfilename"/>
                 <xsl:value-of select="$html.ext"/>
               </xsl:with-param>
            </xsl:call-template>

            <xsl:call-template name="suse:keyvalue">
               <xsl:with-param name="key">X-DOC-Weight</xsl:with-param>
               <xsl:with-param name="value">
                  <xsl:call-template name="suse:calcposition"/>
               </xsl:with-param>
            </xsl:call-template>
        </xsl:with-param>
    </xsl:call-template>
    <xsl:apply-templates />
</xsl:template>


<xsl:template match="preface">
   <xsl:variable name="fn">
      <xsl:call-template name="suse:getfilename"/>
   </xsl:variable>

   <xsl:call-template name="suse:writechunk">
        <xsl:with-param name="filename" select="concat($fn, $desktop.ext)" />
        <xsl:with-param name="filecontent">
            <xsl:text>[Desktop Entry]&#10;</xsl:text>

            <xsl:call-template name="suse:keyvalue">
               <xsl:with-param name="key">Name</xsl:with-param>
               <xsl:with-param name="value" select="normalize-space(title)"/>
               <xsl:with-param name="printlang" select="1"/>
            </xsl:call-template>
            <xsl:call-template name="suse:keyvalue">
               <xsl:with-param name="key">DocPath</xsl:with-param>
               <xsl:with-param name="value" select="concat($docpath, $fn, $html.ext)"/>
            </xsl:call-template>
            <xsl:call-template name="suse:keyvalue">
               <xsl:with-param name="key">X-DOC-Weight</xsl:with-param>
               <xsl:with-param name="value">
                  <xsl:call-template name="suse:calcposition"/>
               </xsl:with-param>
            </xsl:call-template>
        </xsl:with-param>
    </xsl:call-template>
    <xsl:apply-templates />
</xsl:template>


<xsl:template match="chapter">
   <xsl:variable name="dn">
      <xsl:if test="name(..)='part'">
         <xsl:apply-templates mode="recursive-chunk-filename"
            select=".."/>
      </xsl:if>
   </xsl:variable>
   <xsl:variable name="fn">
      <xsl:call-template name="suse:getfilename"/>
   </xsl:variable>
   <xsl:variable name="dir">
      <xsl:if test="$dn">
         <xsl:value-of select="concat(substring-before($dn, $html.ext), '/')"/>
      </xsl:if>
   </xsl:variable>

   <xsl:call-template name="suse:writechunk">
        <xsl:with-param name="directory" select="$dir"/>
        <xsl:with-param name="filename"  select="concat($fn, $desktop.ext)" />
        <xsl:with-param name="filecontent">
            <xsl:text>[Desktop Entry]&#10;</xsl:text>

            <xsl:call-template name="suse:keyvalue">
               <xsl:with-param name="key">Name</xsl:with-param>
               <xsl:with-param name="value" select="normalize-space(title)"/>
               <xsl:with-param name="printlang" select="1"/>
            </xsl:call-template>
            <xsl:call-template name="suse:keyvalue">
               <xsl:with-param name="key">DocPath</xsl:with-param>
               <xsl:with-param name="value" select="concat($docpath, $fn, $html.ext)"/>
            </xsl:call-template>
            <xsl:call-template name="suse:keyvalue">
               <xsl:with-param name="key">X-DOC-Weight</xsl:with-param>
               <xsl:with-param name="value">
                  <xsl:call-template name="suse:calcposition"/>
               </xsl:with-param>
            </xsl:call-template>
        </xsl:with-param>
    </xsl:call-template>
    <xsl:apply-templates />
</xsl:template>


<xsl:template match="appendix">
   <xsl:variable name="dn">
      <xsl:if test="name(..)='part'">
         <xsl:apply-templates mode="recursive-chunk-filename"
            select=".."/>
      </xsl:if>
   </xsl:variable>
   <xsl:variable name="fn">
      <xsl:call-template name="suse:getfilename"/>
   </xsl:variable>
   <xsl:variable name="dir">
      <xsl:if test="$dn">
         <xsl:value-of select="concat(substring-before($dn, $html.ext), '/')"/>
      </xsl:if>
   </xsl:variable>

   <xsl:call-template name="suse:writechunk">
        <xsl:with-param name="directory" select="$dir"/>
        <xsl:with-param name="filename"  select="concat($fn, $desktop.ext)"/>
        <xsl:with-param name="filecontent">
            <xsl:text>[Desktop Entry]&#10;</xsl:text>

            <xsl:call-template name="suse:keyvalue">
               <xsl:with-param name="key">Name</xsl:with-param>
               <xsl:with-param name="value" select="normalize-space(title)"/>
               <xsl:with-param name="printlang" select="1"/>
            </xsl:call-template>
            <xsl:call-template name="suse:keyvalue">
               <xsl:with-param name="key">DocPath</xsl:with-param>
               <xsl:with-param name="value" select="concat($docpath, $fn, $html.ext)"/>
            </xsl:call-template>
            <xsl:call-template name="suse:keyvalue">
               <xsl:with-param name="key">X-DOC-Weight</xsl:with-param>
               <xsl:with-param name="value">
                  <xsl:call-template name="suse:calcposition"/>
               </xsl:with-param>
            </xsl:call-template>
        </xsl:with-param>
    </xsl:call-template>

    <xsl:apply-templates />
</xsl:template>


<xsl:template match="index|glossary|bibliography">
   <xsl:variable name="fn">
      <xsl:call-template name="suse:getfilename"/>
   </xsl:variable>

   <xsl:call-template name="suse:writechunk">
        <xsl:with-param name="directory" />
        <xsl:with-param name="filename" select="concat($fn, $desktop.ext)"/>
        <xsl:with-param name="filecontent">
            <xsl:text>[Desktop Entry]&#10;</xsl:text>

            <xsl:call-template name="suse:keyvalue">
               <xsl:with-param name="key">Name</xsl:with-param>
               <xsl:with-param name="value">
                  <xsl:choose>
                     <xsl:when test="title">
                        <xsl:value-of select="normalize-space(title)"/>
                     </xsl:when>
                     <xsl:otherwise>
                        <xsl:call-template name="gentext">
                           <xsl:with-param name="key" select="'Index'"/>
                        </xsl:call-template>
                     </xsl:otherwise>
                  </xsl:choose>
               </xsl:with-param>
               <xsl:with-param name="printlang" select="1"/>
            </xsl:call-template>
            <xsl:call-template name="suse:keyvalue">
               <xsl:with-param name="key">DocPath</xsl:with-param>
               <xsl:with-param name="value" select="concat($docpath, $fn, $html.ext)"/>
            </xsl:call-template>
            <xsl:call-template name="suse:keyvalue">
               <xsl:with-param name="key">X-DOC-Weight</xsl:with-param>
               <xsl:with-param name="value">
                  <xsl:call-template name="suse:calcposition"/>
               </xsl:with-param>
            </xsl:call-template>
        </xsl:with-param>
    </xsl:call-template>
    <xsl:apply-templates />
</xsl:template>


<!-- ========================================================== -->
<xsl:template name="suse:printtitle">
    <xsl:param name="context" select="title"/>
    <xsl:message>
       <xsl:value-of select="local-name()"/>
       <xsl:text>: &quot;</xsl:text>
       <xsl:value-of select="normalize-space($context)"/>
       <xsl:if test="subtitle">
          <xsl:text> - </xsl:text>
          <xsl:value-of select="normalize-space(subtitle)"/>
       </xsl:if>
       <xsl:text>&quot;</xsl:text>
    </xsl:message>
</xsl:template>


<xsl:template name="suse:calcposition">
    <xsl:param name="value">
        <xsl:number count="part|preface|chapter|appendix|index|glossary|bibliography" level="any"/>
    </xsl:param>
<!--    <xsl:message>
    element = <xsl:value-of select="name(.)"/>
    value   = <xsl:value-of select="$value"/>/<xsl:value-of select="$value*10"/>
    </xsl:message>//-->
    <xsl:value-of select="number($value)*10"/>
</xsl:template>


<xsl:template name="suse:getfilename">
   <xsl:param name="node" select="."/>

   <xsl:choose>
      <xsl:when test="$use.id.as.filename and @id">
         <xsl:value-of select="@id"/>
      </xsl:when>
      <xsl:otherwise>
         <xsl:variable name="tmp">
            <xsl:apply-templates select="$node" mode="recursive-chunk-filename"/>
         </xsl:variable>
         <xsl:value-of select="substring-before($tmp, $html.ext)"/>
      </xsl:otherwise>
   </xsl:choose>
</xsl:template>


<xsl:template name="suse:writechunk">
   <xsl:param name="directory"/>
   <xsl:param name="filename"/>
   <xsl:param name="filecontent" />

    <xsl:call-template name="write.text.chunk">
        <xsl:with-param name="filename" select="concat($outputdir,
           '/', $directory, '/', $filename)"/>
        <xsl:with-param name="content" select="$filecontent"/>
        <xsl:with-param name="encoding" select="$desktop.encoding"/>
    </xsl:call-template>
</xsl:template>


<xsl:template name="suse:debug">
   <xsl:param name="text"/>

   <xsl:if test="$debug">
      <xsl:message><xsl:value-of select="$text"/><xsl:text>&#10;</xsl:text></xsl:message>
   </xsl:if>
</xsl:template>

<!--
<xsl:template name="count.uri.path.depth">
    <xsl:param name="filename"
                select="''"/>
    <xsl:param name="count"
                select="0"/>

    <xsl:choose>
    <xsl:when test="contains($filename, '/')">
        <xsl:call-template name="count.uri.path.depth">
            <xsl:with-param name="filename"
                                select="substring-after($filename, '/')"/>
            <xsl:with-param name="count"
                                select="$count + 1"/>
        </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
        <xsl:value-of select="$count"/>
    </xsl:otherwise>
    </xsl:choose>
</xsl:template>
-->

</xsl:stylesheet>
