<?xml version="1.0" encoding="UTF-8"?>
<!-- $Id: inlines.xsl,v 1.2 2005/09/26 12:18:52 toms Exp $ -->
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:fo="http://www.w3.org/1999/XSL/Format"
    xmlns:svg="http://www.w3.org/2000/svg"
    xmlns:exslt="http://exslt.org/common"
    xmlns:rx="http://www.renderx.com/XSL/Extensions"
    exclude-result-prefixes="exslt"
>

<!-- ==================================================================== -->
<xsl:template name="inline.sansseq">
  <xsl:param name="content">
    <xsl:apply-templates/>
  </xsl:param>
  <fo:inline font-family="{$sans.font.family}">
    <xsl:if test="@id">
      <xsl:attribute name="id">
        <xsl:value-of select="@id"/>
      </xsl:attribute>
    </xsl:if>
    <xsl:if test="@dir">
      <xsl:attribute name="direction">
        <xsl:choose>
          <xsl:when test="@dir = 'ltr' or @dir = 'lro'">ltr</xsl:when>
          <xsl:otherwise>rtl</xsl:otherwise>
        </xsl:choose>
      </xsl:attribute>
    </xsl:if>
    <xsl:copy-of select="$content"/>
  </fo:inline>
</xsl:template>

<xsl:template name="inline.sansboldseq">
  <xsl:param name="content">
    <xsl:apply-templates/>
  </xsl:param>
  <fo:inline font-family="{$sans.font.family}" font-weight="bold">
    <xsl:if test="@id">
      <xsl:attribute name="id">
        <xsl:value-of select="@id"/>
      </xsl:attribute>
    </xsl:if>
    <xsl:if test="@dir">
      <xsl:attribute name="direction">
        <xsl:choose>
          <xsl:when test="@dir = 'ltr' or @dir = 'lro'">ltr</xsl:when>
          <xsl:otherwise>rtl</xsl:otherwise>
        </xsl:choose>
      </xsl:attribute>
    </xsl:if>
    <xsl:copy-of select="$content"/>
  </fo:inline>
</xsl:template>


<xsl:template name="inline.italicseq">
  <xsl:param name="content">
    <xsl:apply-templates/>
  </xsl:param>
  <fo:inline font-style="italic">
    <xsl:if test="@id">
      <xsl:attribute name="id">
        <xsl:value-of select="@id"/>
      </xsl:attribute>
    </xsl:if>
    <xsl:if test="@dir">
      <xsl:attribute name="direction">
        <xsl:choose>
          <xsl:when test="@dir = 'ltr' or @dir = 'lro'">ltr</xsl:when>
          <xsl:otherwise>rtl</xsl:otherwise>
        </xsl:choose>
      </xsl:attribute>
    </xsl:if>
    <xsl:copy-of select="$content"/>
  </fo:inline>
</xsl:template>


<!-- ==================================================================== -->
<!-- As discussed in our conf call from 9 Jun 2005 -->
<xsl:template match="guimenu">
  <xsl:call-template name="inline.italicseq"/>
</xsl:template>


<xsl:template match="keycap">
   <xsl:param name="key.contents" select="."/>
   <xsl:variable name="key.length" select="string-length($key.contents)"/>

   <fo:inline font-size="7.5pt" border="0.45pt solid black"
              padding-top="2pt" padding-bottom="0.75pt"
              padding-left="2pt" padding-right="2pt">
<!--     <xsl:message> keycap (<xsl:value-of select="@function"/>): <xsl:call-template name="gentext.template">
           <xsl:with-param name="context" select="'keycap'"/>
           <xsl:with-param name="name" select="'alt'"/>
         </xsl:call-template>
</xsl:message>-->
     <xsl:choose>
       <xsl:when test="@function">
         <xsl:call-template name="inline.sansseq">
            <xsl:with-param name="content">
               <xsl:call-template name="gentext.template">
                  <xsl:with-param name="context" select="'keycap'"/>
                  <xsl:with-param name="name">
                     <xsl:value-of select="@function"/>
                  </xsl:with-param>
               </xsl:call-template>
            </xsl:with-param>
         </xsl:call-template>
       </xsl:when>
       <xsl:otherwise>
          <xsl:call-template name="inline.sansseq"/>
       </xsl:otherwise>
     </xsl:choose>
   </fo:inline>

   <!--<fo:instream-foreign-object alignment-baseline="central">
     <svg:svg width="{($key.length * 6)+4}pt" height="9pt" version="1.0">
       <svg:rect x="0" y="0"
                 rx="4" ry="4"
                 width="{($key.length * 6)+4}pt" height="9pt"
                 fill="none"
                 stroke="black" stroke-width="0.65pt"/>
         <svg:text x="4pt" y="7pt"
                   text-align="center" vertical-align="middle"
                   font-family="{$monospace.font.family}"
                   font-size="7pt">
           <svg:tspan><xsl:value-of select="$key.contents"/></svg:tspan>
         </svg:text>
     </svg:svg>
   </fo:instream-foreign-object>-->
</xsl:template>


<xsl:template match="para/glossterm">
   <xsl:text>&#x27A2;</xsl:text>
   <xsl:apply-imports/>
</xsl:template>


<xsl:template match="command">
  <xsl:call-template name="inline.monoseq"/>
</xsl:template>


<xsl:template match="keycombo">
  <xsl:variable name="action" select="@action"/>
  <xsl:variable name="joinchar">
    <xsl:choose>
      <xsl:when test="$action='seq'"> &#x2013; </xsl:when>
      <xsl:when test="$action='press'"> + </xsl:when>
      <xsl:when test="$action='other'"></xsl:when>
      <xsl:otherwise> + </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  <xsl:for-each select="*">
    <xsl:if test="position()>1"><xsl:value-of select="$joinchar"/></xsl:if>
    <xsl:apply-templates select="."/>
  </xsl:for-each>
</xsl:template>


<xsl:template match="filename">
  <xsl:variable name="rtf">
     <xsl:apply-templates select="self::filename" mode="copy-node-normal"/>
  </xsl:variable>

  <fo:inline xsl:use-attribute-sets="filename.properties">
     <xsl:apply-templates select="exslt:node-set($rtf)/*" mode="hyphenate-url"/>
  </fo:inline>
</xsl:template>


<xsl:template match="ulink" name="ulink">
  <fo:basic-link>
    <xsl:attribute name="external-destination">
      <xsl:call-template name="fo-external-image">
        <xsl:with-param name="filename" select="@url"/>
      </xsl:call-template>
    </xsl:attribute>

    <fo:inline xsl:use-attribute-sets="ulink.properties">
    <xsl:choose>
      <xsl:when test="count(child::node())=0">
        <xsl:call-template name="hyphenate-url">
          <xsl:with-param name="url" select="@url"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates/>
      </xsl:otherwise>
    </xsl:choose>
    </fo:inline>
  </fo:basic-link>

  <xsl:if test="count(child::node()) != 0
                and string(.) != @url
                and $ulink.show != 0">
    <!-- yes, show the URI -->
    <xsl:choose>
      <xsl:when test="$ulink.footnotes != 0 and not(ancestor::footnote)">
        <fo:footnote>
          <xsl:call-template name="ulink.footnote.number"/>
          <fo:footnote-body xsl:use-attribute-sets="footnote.properties">
            <fo:block>
              <xsl:call-template name="ulink.footnote.number"/>
              <xsl:text> </xsl:text>
              <fo:inline>
                <xsl:value-of select="@url"/>
              </fo:inline>
            </fo:block>
          </fo:footnote-body>
        </fo:footnote>
      </xsl:when>
      <xsl:otherwise>
        <fo:inline hyphenate="false">
          <xsl:text> [</xsl:text>
          <xsl:call-template name="hyphenate-url">
            <xsl:with-param name="url" select="@url"/>
          </xsl:call-template>
          <xsl:text>]</xsl:text>
        </fo:inline>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:if>
</xsl:template>


</xsl:stylesheet>