<?xml version="1.0" encoding="UTF-8"?>
<!-- $Id: sections.xsl,v 1.1 2005/09/26 11:56:26 toms Exp $ -->
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:fo="http://www.w3.org/1999/XSL/Format"
>


<xsl:template name="section.heading">
  <xsl:param name="level" select="1"/>
  <xsl:param name="marker" select="1"/>
  <xsl:param name="title"/>
  <xsl:param name="titleabbrev"/>


  <xsl:variable name="_label">
   <xsl:apply-templates select="parent::*[1]" mode="label.markup"/>
  </xsl:variable>

  <xsl:variable name="_title">
   <xsl:apply-templates select="." mode="title.markup"/>
  </xsl:variable>

  <xsl:variable name="_list">
   <fo:list-item>
      <fo:list-item-label end-indent="label-end()">
         <fo:block><xsl:value-of select="$_label"/></fo:block>
      </fo:list-item-label>
      <fo:list-item-body start-indent="body-start()">
         <fo:block><xsl:value-of select="$_title"/></fo:block>
      </fo:list-item-body>
   </fo:list-item>
  </xsl:variable>

  <xsl:variable name="head.marker">
    <xsl:if test="$marker != 0">
      <fo:marker marker-class-name="section.head.marker">
        <xsl:choose>
          <xsl:when test="$titleabbrev = ''">
            <xsl:value-of select="$title"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="$titleabbrev"/>
          </xsl:otherwise>
        </xsl:choose>
      </fo:marker>
    </xsl:if>
  </xsl:variable>

<!--  <xsl:message>
    name  = <xsl:value-of select="name()"/>
    test  = "<xsl:value-of select="$_label=''"/>"
    label = "<xsl:value-of select="$_label"/>"
    title = "<xsl:value-of select="$_title"/>"
    level = "<xsl:value-of select="$level"/>/<xsl:value-of select="$section.autolabel.max.depth"/>=<xsl:value-of select="$level >= $section.autolabel.max.depth"/>"
  </xsl:message>-->

 <xsl:choose>
   <xsl:when test="$level > $section.autolabel.max.depth">
      <xsl:choose>
        <xsl:when test="$level=1">
          <fo:block xsl:use-attribute-sets="section.title.properties
        section.title.level1.properties"><xsl:copy-of select="$_title"/></fo:block>
        </xsl:when>
        <xsl:when test="$level=2">
          <fo:block xsl:use-attribute-sets="section.title.properties
        section.title.level2.properties"><xsl:copy-of select="$_title"/></fo:block>
        </xsl:when>
        <xsl:when test="$level=3">
          <fo:block xsl:use-attribute-sets="section.title.properties
        section.title.level3.properties"><xsl:copy-of select="$_title"/></fo:block>
        </xsl:when>
        <xsl:when test="$level=4">
          <fo:block xsl:use-attribute-sets="section.title.properties
        section.title.level4.properties"><xsl:copy-of select="$_title"/></fo:block>
        </xsl:when>
        <xsl:otherwise>
          <fo:block><xsl:copy-of select="$_title"/></fo:block>
        </xsl:otherwise>
      </xsl:choose>
   </xsl:when>
   <xsl:otherwise>
    <xsl:choose>
      <xsl:when test="$level=1">
        <fo:block xsl:use-attribute-sets="section.title.properties
                                          section.title.level1.properties">
         <xsl:copy-of select="$head.marker"/>
         <fo:list-block provisional-label-separation="0.75em">
          <xsl:attribute name="provisional-distance-between-starts">
             <xsl:value-of select="string-length($_label)*0.75"/>
             <xsl:text>em</xsl:text>
          </xsl:attribute>
          <xsl:copy-of select="$_list"/>
         </fo:list-block>
        </fo:block>
      </xsl:when>
      <xsl:when test="$level=2">
        <fo:block xsl:use-attribute-sets="section.title.properties
                                          section.title.level2.properties">
         <xsl:copy-of select="$head.marker"/>
         <fo:list-block provisional-label-separation="0.6em">
          <xsl:attribute name="provisional-distance-between-starts">
             <xsl:value-of select="string-length($_label)*0.6"/>
             <xsl:text>em</xsl:text>
          </xsl:attribute>
          <xsl:copy-of select="$_list"/>
         </fo:list-block>
        </fo:block>
      </xsl:when>
      <xsl:when test="$level=3">
        <fo:block xsl:use-attribute-sets="section.title.properties
                                          section.title.level3.properties">
         <xsl:copy-of select="$head.marker"/>
         <fo:list-block provisional-label-separation="0.7em">
          <xsl:attribute name="provisional-distance-between-starts">
             <xsl:value-of select="string-length($_label)*0.7"/>
             <xsl:text>em</xsl:text>
          </xsl:attribute>
          <xsl:copy-of select="$_list"/>
         </fo:list-block>
        </fo:block>
      </xsl:when>
      <xsl:when test="$level=4">
        <fo:block xsl:use-attribute-sets="section.title.properties
                                          section.title.level4.properties">
         <xsl:copy-of select="$head.marker"/>
         <fo:list-block provisional-label-separation="0.8em">
          <xsl:attribute name="provisional-distance-between-starts">
             <xsl:value-of select="string-length($_label)*0.8"/>
             <xsl:text>em</xsl:text>
          </xsl:attribute>
          <xsl:copy-of select="$_list"/>
         </fo:list-block>
        </fo:block>
      </xsl:when>
      <xsl:when test="$level=5">
        <fo:block xsl:use-attribute-sets="section.title.properties
                                          section.title.level5.properties">
         <xsl:copy-of select="$head.marker"/>
         <fo:list-block
                        provisional-label-separation="1em">
          <xsl:attribute name="provisional-distance-between-starts">
             <xsl:value-of select="string-length($_label)*0.8"/>
             <xsl:text>em</xsl:text>
          </xsl:attribute>
          <xsl:copy-of select="$_list"/>
         </fo:list-block>
        </fo:block>
      </xsl:when>
      <xsl:otherwise>
        <fo:block xsl:use-attribute-sets="section.title.properties
                                          section.title.level6.properties">
         <xsl:copy-of select="$head.marker"/>
         <fo:list-block provisional-label-separation="1em">
          <xsl:copy-of select="$_list"/>
         </fo:list-block>
        </fo:block>
      </xsl:otherwise>
    </xsl:choose>
   </xsl:otherwise>
  </xsl:choose>
</xsl:template>



</xsl:stylesheet>
