<?xml version="1.0" encoding="ISO-8859-1"?>
<!-- $Id: redefinitions.xsl,v 1.1 2005/05/13 09:23:04 toms Exp $ -->
<xsl:stylesheet
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:l="http://docbook.sourceforge.net/xmlns/l10n/1.0">


<!-- Other templates -->
<xsl:template match="authorgroup" mode="titlepage.mode">
  <table width="100%" xmlns="http://www.w3.org/1999/xhtml" class="{name(.)}">
   <tbody>
    <tr valign="top">
     <td width="15%">
     <xsl:choose>
       <xsl:when test="@role='authors'">
        <xsl:variable name="authors">
        <xsl:call-template name="gentext">
            <xsl:with-param name="key" select="'Authors'"/>
        </xsl:call-template>
        </xsl:variable>
        <xsl:value-of select="$authors"/>
       </xsl:when>
       <xsl:when test="@role='office'">
        <xsl:call-template name="gentext">
            <xsl:with-param name="key" select="'Office'"/>
        </xsl:call-template>
       </xsl:when>
       <xsl:when test="@role='translators'">
      <xsl:if test="not(/book/@lang='de')">
         <xsl:call-template name="gentext">
            <xsl:with-param name="key" select="'Translators'"/>
         </xsl:call-template>
      </xsl:if>
       </xsl:when>
       <xsl:otherwise>
        <!-- needs to be checked -->
        <xsl:text>Mitarbeiter:</xsl:text>
       </xsl:otherwise>
     </xsl:choose>
    </td>
    <xsl:if test="not(@role='translators' and /book/@lang='de')">
     <td><xsl:apply-templates mode="titlepage.mode"/></td>
   </xsl:if>
    </tr>
   </tbody>
  </table>
</xsl:template>


<xsl:template match="author|othercredit" mode="titlepage.mode">
   <span xmlns="http://www.w3.org/1999/xhtml" class="{name(.)}">
      <xsl:call-template name="person.name"/>
      <xsl:apply-templates mode="titlepage.mode" select="./contrib"/>
      <xsl:apply-templates mode="titlepage.mode" select="./affiliation"/>
        <xsl:if test="count(following-sibling::author)>0 or
                      count(following-sibling::othercredit)>0">
         <xsl:text>, </xsl:text>
      </xsl:if>
   </span>
</xsl:template>


<xsl:template match="authorgroup[@role='translators']/author" mode="titlepage.mode">
   <span xmlns="http://www.w3.org/1999/xhtml" class="{name(.)}">
      <xsl:call-template name="person.name"/>
      <xsl:if test="count(following-sibling::author)>0">
            <xsl:if test="string-length(following-sibling::author/firstname)>0">
            <xsl:text>, </xsl:text>
         </xsl:if>
      </xsl:if>
   </span>
</xsl:template>

<!-- productname is now the title of the book -->
<xsl:template match="bookinfo/productname" mode="titlepage.mode">
   <div>
      <h1 class="title">
         <xsl:apply-templates/>
      </h1>
   </div>
</xsl:template>


<!-- titleabbrev is now the subtitle of the book -->
<xsl:template match="bookinfo/titleabbrev" mode="titlepage.mode">
   <div>
      <h2 class="subtitle">
         <xsl:apply-templates/>
      </h2>
   </div>

</xsl:template>


<xsl:template match="guimenu|guisubmenu">
    <!-- lsquo=2018, rsquo=2019 -->
    <span class="{local-name()}">
        <xsl:text>&#x2018;</xsl:text>
        <xsl:call-template name="inline.charseq"/>
        <xsl:text>&#x2019;</xsl:text>
    </span>
</xsl:template>

<xsl:template match="guilabel|guibutton|guiicon">
    <span class="{local-name()}">
        <xsl:call-template name="inline.charseq"/>
    </span>
</xsl:template>


<xsl:template match="application">
    <span class="{local-name()}">
        <xsl:call-template name="inline.charseq"/>
    </span>
</xsl:template>

<!--<xsl:template name="inline.charseq">
  <xsl:param name="content">
    <xsl:call-template name="anchor"/>
    <xsl:call-template name="simple.xlink">
      <xsl:with-param name="content">
        <xsl:apply-templates/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:param>
    <span class="{name()}">
        <xsl:copy-of select="$content"/>
    </span>
</xsl:template>//-->

<xsl:template match="para[@arch]">
  <xsl:call-template name="paragraph">
    <xsl:with-param name="class">
      <xsl:if test="@role and $para.propagates.style != 0">
        <xsl:value-of select="@role"/>
      </xsl:if>
    </xsl:with-param>
    <xsl:with-param name="content">
      <xsl:text>&#x25aa;&#xa0;</xsl:text><!-- &squf; -->
      <b><xsl:value-of select="@arch"/></b><br/>
      <xsl:if test="position() = 1 and parent::listitem">
        <xsl:call-template name="anchor">
          <xsl:with-param name="node" select="parent::listitem"/>
        </xsl:call-template>
      </xsl:if>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates/>
      <xsl:text>&#x25aa;</xsl:text><!-- &marker; -->
    </xsl:with-param>
  </xsl:call-template>
</xsl:template>


<xsl:template name="graphical.admonition">
  <xsl:variable name="admon.type">
    <xsl:choose>
      <xsl:when test="local-name(.)='note'">Note</xsl:when>
      <xsl:when test="local-name(.)='warning'">Warning</xsl:when>
      <xsl:when test="local-name(.)='caution'">Caution</xsl:when>
      <xsl:when test="local-name(.)='tip'">Tip</xsl:when>
      <xsl:when test="local-name(.)='important'">Important</xsl:when>
      <xsl:otherwise>Note</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <div class="{name(.)}">
    <xsl:if test="$admon.style != ''">
      <xsl:attribute name="style">
        <xsl:value-of select="$admon.style"/>
      </xsl:attribute>
    </xsl:if>

    <table border="0" cellpadding="3" cellspacing="0" width="100%">
      <xsl:attribute name="summary">
        <xsl:value-of select="$admon.type"/>
        <xsl:if test="title">
          <xsl:text>: </xsl:text>
          <xsl:value-of select="title"/>
        </xsl:if>
      </xsl:attribute>
      <tr class="head">
        <td><!-- ***  -->
          <xsl:attribute name="width">
            <!--<xsl:apply-templates mode="admon.graphic.width"/>-->
            <xsl:value-of select="$admon.graphic.width"/>
          </xsl:attribute>
          <img alt="[{$admon.type}]">
            <xsl:attribute name="src">
              <xsl:call-template name="admon.graphic"/>
            </xsl:attribute>
          </img>
        </td>
        <th align="left">
          <xsl:call-template name="anchor"/>
          <xsl:if test="$admon.textlabel != 0 or title">
            <xsl:apply-templates select="." mode="object.title.markup"/>
          </xsl:if>
        </th>
      </tr>
      <tr>
        <td colspan="2" align="left" valign="top">
          <xsl:apply-templates/>
        </td>
      </tr>
    </table>
  </div>
</xsl:template>


<xsl:template name="xml.base.dirs">
   <!-- Empty, because we don't want that our graphics
        path are influenced by xml:base attributes
    -->
</xsl:template>

<!--<xsl:template match="*" mode="admon.graphic.width">
  <xsl:param name="node" select="."/>
  <xsl:text>0</xsl:text>
</xsl:template>-->

</xsl:stylesheet>
